@@ -7,7 +7,6 @@ from flexget.event import event
 from flexget.utils import requests, json
 from flexget.utils.search import torrent_availability
 
-session = requests.Session()
 log = logging.getLogger('search_btn')
 
 # TODO: btn has a limit of 150 searches per hour
@@ -16,7 +15,7 @@ log = logging.getLogger('search_btn')
 class SearchBTN(object):
     schema = {'type': 'string'}
 
-    def search(self, entry, config):
+    def search(self, task, entry, config):
         api_key = config
 
         searches = entry.get('search_strings', [entry['title']])
@@ -35,7 +34,8 @@ class SearchBTN(object):
         for search in searches:
             data = json.dumps({'method': 'getTorrents', 'params': [api_key, search], 'id': 1})
             try:
-                r = session.post('http://api.btnapps.net/', data=data, headers={'Content-type': 'application/json'})
+                r = task.requests.post('http://api.btnapps.net/',
+                                       data=data, headers={'Content-type': 'application/json'})
             except requests.RequestException as e:
                 log.error('Error searching btn: %s' % e)
                 continue
